# Virtual Warehouse
[![Documentation Status](https://readthedocs.org/projects/virtual-warehouse/badge/?version=latest)](https://virtual-warehouse.readthedocs.io/en/latest/?badge=latest) 
[![DeepSource](https://deepsource.io/gh/Breta01/virtual-warehouse.svg/?label=active+issues&show_trend=true)](https://deepsource.io/gh/Breta01/virtual-warehouse/?ref=repository-badge)

Visualisation of warehouse
